{% extends "allauth_ens/base.html" %}
{% load i18n %}

{% block title %}{% trans "Password Reset" %}{% endblock %}
{% block header-title %}{% trans "Password Reset" %}{% endblock %}

{% block content %}

<section>
  <p>
    {% blocktrans %}
    We have sent you an e-mail. Please contact us if you do not receive it within a few minutes.
    {% endblocktrans %}
  </p>
</section>

{% endblock %}
